import { type AutocompleteStringList, type StringListToInterfaceKey } from "../utils.js";
declare const DEFAULT_COMMENTS: readonly ["json", "jsonl"];
type Comments = AutocompleteStringList<(typeof DEFAULT_COMMENTS)[number]>;
type DefaultCommentsHolder = StringListToInterfaceKey<typeof DEFAULT_COMMENTS>;
declare const DEFAULT_TAGS: readonly ["json", "jsonl"];
type Tags = AutocompleteStringList<(typeof DEFAULT_TAGS)[number]>;
type DefaultTagsHolder = StringListToInterfaceKey<typeof DEFAULT_TAGS>;
declare const JSON_PARSERS: readonly ["json", "json5", "jsonc", "json-stringify"];
type JsonParser = (typeof JSON_PARSERS)[number];
declare const EMBEDDED_LANGUAGE_IDENTIFIERS: "embeddedJsonIdentifiers";
declare const EMBEDDED_LANGUAGE_COMMENTS: "embeddedJsonComments";
declare const EMBEDDED_LANGUAGE_TAGS: "embeddedJsonTags";
declare const EMBEDDED_LANGUAGE_PARSER: "embeddedJsonParser";
export declare const options: {
    readonly embeddedJsonIdentifiers: {
        readonly category: "Embed";
        readonly type: "string";
        readonly array: true;
        readonly default: [{
            readonly value: ["json", "jsonl"];
        }];
        readonly description: "Tag or comment identifiers that make their subsequent template literals be identified as embedded JSON language.";
        readonly deprecated: "Please use `embeddedJsonComments` or `embeddedJsonTags`.";
    };
    readonly embeddedJsonComments: {
        readonly category: "Embed";
        readonly type: "string";
        readonly array: true;
        readonly default: [{
            readonly value: ["9ff2b366e8ca4c97b9aed1a29b5b94ed"];
        }];
        readonly description: "Block comments that make their subsequent template literals be identified as embedded JSON language.";
    };
    readonly embeddedJsonTags: {
        readonly category: "Embed";
        readonly type: "string";
        readonly array: true;
        readonly default: [{
            readonly value: ["9ff2b366e8ca4c97b9aed1a29b5b94ed"];
        }];
        readonly description: "Tags that make their subsequent template literals be identified as embedded JSON language.";
    };
    readonly embeddedJsonParser: {
        category: string;
        type: "choice";
        default: "json";
        description: string;
        choices: {
            value: "json" | "json5" | "jsonc" | "json-stringify";
            description: string;
        }[];
    };
};
type Options = typeof options;
declare module "../types.js" {
    interface EmbeddedOptions extends Options {
    }
    interface EmbeddedDefaultCommentsHolder extends DefaultCommentsHolder {
    }
    interface EmbeddedDefaultTagsHolder extends DefaultTagsHolder {
    }
    interface PluginEmbedOptions {
        /**
         * @deprecated Please use `embeddedJsonComments` or `embeddedJsonTags`.
         */
        [EMBEDDED_LANGUAGE_IDENTIFIERS]?: (Comments[number] | Tags[number])[];
        [EMBEDDED_LANGUAGE_COMMENTS]?: Comments;
        [EMBEDDED_LANGUAGE_TAGS]?: Tags;
        [EMBEDDED_LANGUAGE_PARSER]?: JsonParser;
    }
}
export {};
